<?php
namespace Ep\Middleware;

use Interop\Container\ContainerInterface;
use Zend\ServiceManager\Factory\FactoryInterface;
use Zend\Stratigility\MiddlewarePipe;

/**
 * Stvara novu instancu EP Aplikacije.
 *
 * @package Ep\Middleware
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/core
 */
class AppFactory implements FactoryInterface
{
    /**
     * Stvara aplikaciju.
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return object
     *
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $config = $container->get('config')['app'] ?? [];
        $app = new MiddlewarePipe();

        foreach ($config['middleware'] ?? [] as $middleware) {
            if (is_string($middleware)) {
                $middleware = $container->get($middleware);
            }

            $app->pipe($middleware);
        }

        return $app;
    }
}